import { UserInfo } from '@empathyco/x-types';
import { StorageService } from '@empathyco/x-storage-service';
import { Container } from 'inversify';
import { DeepPartial, FeatureNames, Newable } from '../../types';
import { EmpathyAdapterConfig, FacetConfig, FeatureConfig } from '../config/empathy-adapter-config.types';
import { DEPENDENCIES } from '../container/container.const';
import { BeforeRequest, BeforeResponseTransform, MapRequest, MapResponse, RequestMapper, ResponseMapper, ResponseTransformed } from '../empathy-adapter.types';
import { EmpathyAdapter } from '../empathy.adapter';
import { EntityNames } from '../entities.types';
import { CacheService } from '../services/cache-service.types';
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @internal
 */
declare type ConfiguratorCallback = (container: Container) => void;
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @internal
 */
interface EnableCacheOptions {
    storageService?: StorageService;
    cacheService?: Newable<CacheService>;
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare class EmpathyAdapterBuilder {
    protected container: Container;
    protected defaultBindingsConfig: import("..").BindingDictionary;
    protected adapterClass: Newable<EmpathyAdapter>;
    protected configurator?: ConfiguratorCallback;
    protected config: EmpathyAdapterConfig;
    constructor(container?: Container, defaultBindingsConfig?: import("..").BindingDictionary, adapterClass?: Newable<EmpathyAdapter>);
    enableCache({ storageService, cacheService }?: EnableCacheOptions): this;
    addClassMapper<Entity>(mapper: Newable<ResponseMapper<Entity>>, entity: EntityNames, feature?: FeatureNames): this;
    addMapper(mapper: MapResponse, entity: EntityNames, feature?: FeatureNames): this;
    replaceMapper(mapper: MapResponse, entity: EntityNames): this;
    replaceClassMapper<Entity>(mapper: Newable<ResponseMapper<Entity>>, entity: EntityNames): this;
    addClassRequestMapper<Entity>(mapper: Newable<ResponseMapper<Entity>>, feature?: FeatureNames): this;
    addRequestMapper(mapper: MapResponse, feature?: FeatureNames): this;
    replaceRequestMapper(mapper: MapRequest): this;
    replaceClassRequestMapper(mapper: Newable<RequestMapper>): this;
    onResponseTransformed<RawResponseType = any, ResponseType = any>(hook: ResponseTransformed<RawResponseType, ResponseType>, feature?: FeatureNames): this;
    onBeforeRequest(hook: BeforeRequest, feature?: FeatureNames): this;
    onBeforeResponseTransformed<RawResponseType = any>(hook: BeforeResponseTransform<RawResponseType>, feature?: FeatureNames): this;
    configureContainer(configurator: ConfiguratorCallback): this;
    setRequestParams(requestParams: Record<string, string>): this;
    setLang(lang: string): this;
    setScope(scope: string): this;
    setInstance(instance: string): this;
    setUserInfo(user: UserInfo): this;
    setEnvironment(environment: EmpathyAdapterConfig['env']): this;
    setFeatureConfig<Feature extends FeatureNames>(featureName: Feature, featureConfig: DeepPartial<FeatureConfig<Feature>>): this;
    setResultTrackingConfig(resultTrackingConfig: DeepPartial<EmpathyAdapterConfig['mappings']['tracking']['result']>): this;
    setFacetConfig(config: DeepPartial<FacetConfig>, facetId?: string): this;
    setQueryConfig(queryConfig: DeepPartial<EmpathyAdapterConfig['mappings']['query']>): this;
    withConfiguration(config: DeepPartial<EmpathyAdapterConfig>): this;
    build(): EmpathyAdapter;
    protected initContainerBindings(): void;
    protected createMapperClass(mapFn: MapResponse): Newable<ResponseMapper>;
    protected createRequestMapperClass(mapFn: MapRequest): Newable<RequestMapper>;
    protected addHook(hook: Function, hookName: keyof typeof DEPENDENCIES.Hooks, feature?: FeatureNames): this;
    protected completePartialFacetsConfig(): void;
}
export {};
